==> flutter_mylibrary-0.5.41.tar.gz: lib/widget/video/video_control_widget.dart <==
import 'dart:async';
import 'dart:math';
import 'package:flutter_mylibrary/flutter_mylibrary.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mylibrary/utils/utils.dart';
import 'package:flutter_mylibrary/utils/win_media.dart';
import 'package:flutter_mylibrary/widget/widget_template.dart';
import 'package:video_player/video_player.dart';
import 'custom_track_shape.dart';
import 'easy_video_player_contrller.dart';

// ignore: must_be_immutable
class VideoControlWidget extends StatelessWidget{


  ///进度条
  ValueNotifier<double> seekBarValueNotifier = ValueNotifier(null);

  @override
  Widget build(BuildContext context) {
    final EasyVideoPlayerController easyVideoPlayerController = Provider.of<EasyVideoPlayerController>(context);

    if(isEmpty(easyVideoPlayerController)){
      return Container();
    }else{
      return ChangeNotifierProvider.value(
          value: easyVideoPlayerController,
          child: Consumer<EasyVideoPlayerController>(
            builder: (_, easyVideoPlayerController, __){
              EasyVideoState state = easyVideoPlayerController.easyVideoState;
              IconData iconData;
              if(state == EasyVideoState.Playing){
                iconData = Icons.pause;
              }else if(state != EasyVideoState.Playing && state != EasyVideoState.Buffering){
                iconData = Icons.play_arrow;
              }
              return Stack(
                children: [
                  AnimatedOpacity(
                    opacity: state == EasyVideoState.Ready || state == EasyVideoState.Error? 1 : 0,
                    duration: const Duration(milliseconds: 300),
                    child: ExtendedImage.network(
                      easyVideoPlayerController.cover,
                      enableLoadState: false,
                      width: double.infinity,
                      fit: BoxFit.fill,
                    ),
                  ),

                  ValueListenableBuilder<bool>(
                      valueListenable: easyVideoPlayerController.showVideoStateNotifier,
                      builder: (_, showState, __){
                        return AnimatedOpacity(
                          opacity: showState  ? 1 : 0,
                          duration: const Duration(milliseconds: 300),
                          child: Stack(
                            children: [

                              SizedBox(
                                width: double.infinity,
                                height: double.infinity,
                                child: Column(
                                  children: [
                                    Expanded(
                                      child: GestureDetector(
                                        onTapDown: (TapDownDetails details){
                                          easyVideoPlayerController.switchPlayState();
                                          easyVideoPlayerController.startHideStateCountDown();
                                        },
                                        child: Container(
                                          color: Colors.transparent,
                                          width: double.infinity,
                                          height: double.infinity,
                                        ),
                                      ),
                                    ),
                                    buildSeekBar(easyVideoPlayerController, context)
                                  ],
                                ),
                              ),


                              Center(
                                child: state == EasyVideoState.Buffering? SpinKitRing(
                                  color: Colors.white,
                                  lineWidth: 2,
                                ) : buildConnerContainer(
                                    onTap: (){
                                      if(showState){
                                        if(state == EasyVideoState.Playing){
                                          easyVideoPlayerController.pause();
                                        }else{
                                          easyVideoPlayerController.play();
                                          easyVideoPlayerController.startHideStateCountDown();
                                        }
                                      }else{
                                        easyVideoPlayerController.showPlayState();
                                      }
                                    },
                                    behavior: HitTestBehavior.opaque,
                                    padding: getEdgeInsetsAll(5),
                                    isCircle: true,
                                    borderColor: Colors.white,
                                    borderWidth: 1,
                                    backgroundColor: Colors.grey.withAlpha(90),
                                    child: Icon(iconData, size: getSp(35), color: Colors.white,)
                                ),
                              ),
                            ],
                          ),
                        );
                      }
                  )
                ],
              );
            },
          ),
      );
    }
  }




  ///进度条
  Widget buildSeekBar(EasyVideoPlayerController easyVideoPlayerController, BuildContext context){

    VideoPlayerController videoPlayerController = easyVideoPlayerController.videoPlayerController;

    TextStyle timeStyle = TextStyle(
        fontSize: getSp(16),
        color: Colors.white
    );
    double thumbSize = 8;

    double trackHeight = 5;

    double trackPadding = 10;

    return buildConnerContainer(
        alignment: Alignment.center,
        padding: getEdgeInsetsSymmetric(horizontal: 10),
        backgroundColor: Colors.transparent,
        child: Stack(
          children: [
            ///缓冲条
            // SliderTheme(
            //   data: SliderThemeData(
            //     trackHeight: 2,
            //     trackShape: CustomTrackShape(),
            //     thumbShape: SliderComponentShape.noThumb,
            //     activeTrackColor: Colors.grey.withAlpha(90),
            //     inactiveTrackColor: Colors.grey.withAlpha(60),
            //   ),
            //   child: Container(
            //     height: 4,
            //     child: Slider(
            //       min: 0.0,
            //       max: _videoPlayerValue.duration.inMilliseconds.toDouble(),
            //       value: _videoPlayerValue.position.inMilliseconds.toDouble(),
            //     ),
            //   ),
            // ),

            Row(
              children: [
                Text(
                  getDurationFormat(easyVideoPlayerController.position),
                  style: timeStyle,
                ),
                Gaps.getHorizontal(trackPadding),
                Expanded(
                  child: SliderTheme(
                    data: SliderThemeData(
                      trackHeight: trackHeight,
                      trackShape: CustomTrackShape(),
                      thumbShape: RoundSliderThumbShape(
                          enabledThumbRadius: thumbSize
                      ),
                      thumbColor: Colors.white,
                      activeTrackColor: Colors.white,
                      inactiveTrackColor: Colors.grey.withAlpha(60),
                    ),
                    child: ValueListenableBuilder(
                      valueListenable: seekBarValueNotifier,
                      builder: (_, _dragValue, __){
                        return Slider(
                          min: 0.0,
                          max: easyVideoPlayerController.duration.inMilliseconds.toDouble(),
                          value: min(_dragValue ?? easyVideoPlayerController.position.inMilliseconds.toDouble(),
                              easyVideoPlayerController.duration.inMilliseconds.toDouble()),
                          onChanged: (value){
                            seekBarValueNotifier.value = value;
                            videoPlayerController.seekTo(Duration(milliseconds: value.round()));
                            easyVideoPlayerController.isSmoothing = true;
                          },
                          onChangeEnd: (value){
                            if(!easyVideoPlayerController.isPlaying){
                              videoPlayerController.play();
                            }
                            easyVideoPlayerController.isSmoothing = false;
                            easyVideoPlayerController.startHideStateCountDown();
                            seekBarValueNotifier.value = null;
                          },
                        );
                      },
                    ),
                  ),
                ),
                Gaps.getHorizontal(trackPadding),
                Text(
                  getDurationFormat(easyVideoPlayerController.duration),
                  style: timeStyle,
                ),

                Gaps.getHorizontal(5),

                GestureDetector(
                  onTap: (){
                    easyVideoPlayerController.toggleFullScreen(context);
                  },
                  child: Icon(CupertinoIcons.viewfinder, size: getSp(25), color: Colors.white,),
                )
              ],
            )
          ],
        )
    );
  }


  String getDurationFormat(Duration duration){
    return RegExp(r'((^0*[1-9]\d*:)?\d{2}:\d{2})\.\d+$')
        .firstMatch("$duration")
        ?.group(1) ??
        '$duration';
  }

}

==> flutter_mylibrary-0.5.53.tar.gz: lib/widget/video/video_control_widget.dart <==
import 'dart:async';
import 'dart:math';
import 'package:flutter_mylibrary/flutter_mylibrary.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mylibrary/utils/utils.dart';
import 'package:flutter_mylibrary/utils/win_media.dart';
import 'package:flutter_mylibrary/widget/widget_template.dart';
import 'package:video_player/video_player.dart';
import 'custom_track_shape.dart';
import 'easy_video_contrller.dart';

// ignore: must_be_immutable
class VideoControlWidget extends StatelessWidget{


  ///进度条
  ValueNotifier<double> seekBarValueNotifier = ValueNotifier(null);

  @override
  Widget build(BuildContext context) {
    final EasyVideoController easyVideoPlayerController = EasyVideoController.of(context);

    if(isEmpty(easyVideoPlayerController)){
      return Container();
    }else{
      return ChangeNotifierProvider.value(
          value: easyVideoPlayerController,
          child: Consumer<EasyVideoController>(
            builder: (_, easyVideoPlayerController, __){
              EasyVideoState state = easyVideoPlayerController.easyVideoState;
              IconData iconData;
              if(state == EasyVideoState.Playing){
                iconData = Icons.pause;
              }else if(state != EasyVideoState.Playing && state != EasyVideoState.Buffering){
                iconData = Icons.play_arrow;
              }
              return Stack(
                children: [
                  AnimatedOpacity(
                    opacity: state == EasyVideoState.Ready || state == EasyVideoState.Error? 1 : 0,
                    duration: const Duration(milliseconds: 300),
                    child: ExtendedImage.network(
                      easyVideoPlayerController.cover,
                      enableLoadState: false,
                      width: double.infinity,
                      fit: BoxFit.fill,
                    ),
                  ),

                  ValueListenableBuilder<bool>(
                      valueListenable: easyVideoPlayerController.showVideoStateNotifier,
                      builder: (_, showState, __){
                        return AnimatedOpacity(
                          opacity: showState  ? 1 : 0,
                          duration: const Duration(milliseconds: 300),
                          child: Stack(
                            children: [

                              SizedBox(
                                width: double.infinity,
                                height: double.infinity,
                                child: Column(
                                  children: [
                                    Expanded(
                                      child: GestureDetector(
                                        onTapDown: (TapDownDetails details){
                                          easyVideoPlayerController.switchPlayState();
                                          easyVideoPlayerController.startHideStateCountDown();
                                        },
                                        child: Container(
                                          color: Colors.transparent,
                                          width: double.infinity,
                                          height: double.infinity,
                                        ),
                                      ),
                                    ),
                                    buildSeekBar(easyVideoPlayerController, context)
                                  ],
                                ),
                              ),


                              Center(
                                child: state == EasyVideoState.Buffering? SpinKitRing(
                                  color: Colors.white,
                                  lineWidth: 2,
                                ) : buildConnerContainer(
                                    onTap: (){
                                      if(showState){
                                        if(state == EasyVideoState.Playing){
                                          easyVideoPlayerController.pause();
                                        }else{
                                          easyVideoPlayerController.play();
                                          easyVideoPlayerController.startHideStateCountDown();
                                        }
                                      }else{
                                        easyVideoPlayerController.showPlayState();
                                      }
                                    },
                                    behavior: HitTestBehavior.opaque,
                                    padding: getEdgeInsetsAll(5),
                                    isCircle: true,
                                    borderColor: Colors.white,
                                    borderWidth: 1,
                                    backgroundColor: Colors.grey.withAlpha(90),
                                    child: Icon(iconData, size: getSp(35), color: Colors.white,)
                                ),
                              ),
                            ],
                          ),
                        );
                      }
                  )
                ],
              );
            },
          ),
      );
    }
  }




  ///进度条
  Widget buildSeekBar(EasyVideoController easyVideoPlayerController, BuildContext context){

    VideoPlayerController videoPlayerController = easyVideoPlayerController.videoPlayerController;

    TextStyle timeStyle = TextStyle(
        fontSize: getSp(16),
        color: Colors.white
    );
    double thumbSize = 8;

    double trackHeight = 5;

    double trackPadding = 10;

    return buildConnerContainer(
        alignment: Alignment.center,
        padding: getEdgeInsetsSymmetric(horizontal: 10),
        backgroundColor: Colors.transparent,
        child: Stack(
          children: [
            ///缓冲条
            // SliderTheme(
            //   data: SliderThemeData(
            //     trackHeight: 2,
            //     trackShape: CustomTrackShape(),
            //     thumbShape: SliderComponentShape.noThumb,
            //     activeTrackColor: Colors.grey.withAlpha(90),
            //     inactiveTrackColor: Colors.grey.withAlpha(60),
            //   ),
            //   child: Container(
            //     height: 4,
            //     child: Slider(
            //       min: 0.0,
            //       max: _videoPlayerValue.duration.inMilliseconds.toDouble(),
            //       value: _videoPlayerValue.position.inMilliseconds.toDouble(),
            //     ),
            //   ),
            // ),

            Row(
              children: [
                Text(
                  getDurationFormat(easyVideoPlayerController.position),
                  style: timeStyle,
                ),
                Gaps.getHorizontal(trackPadding),
                Expanded(
                  child: SliderTheme(
                    data: SliderThemeData(
                      trackHeight: trackHeight,
                      trackShape: CustomTrackShape(),
                      thumbShape: RoundSliderThumbShape(
                          enabledThumbRadius: thumbSize
                      ),
                      thumbColor: Colors.white,
                      activeTrackColor: Colors.white,
                      inactiveTrackColor: Colors.grey.withAlpha(60),
                    ),
                    child: ValueListenableBuilder(
                      valueListenable: seekBarValueNotifier,
                      builder: (_, _dragValue, __){
                        return Slider(
                          min: 0.0,
                          max: easyVideoPlayerController.duration.inMilliseconds.toDouble(),
                          value: min(_dragValue ?? easyVideoPlayerController.position.inMilliseconds.toDouble(),
                              easyVideoPlayerController.duration.inMilliseconds.toDouble()),
                          onChanged: (value){
                            seekBarValueNotifier.value = value;
                            videoPlayerController.seekTo(Duration(milliseconds: value.round()));
                            easyVideoPlayerController.isSmoothing = true;
                          },
                          onChangeEnd: (value){
                            if(!easyVideoPlayerController.isPlaying){
                              videoPlayerController.play();
                            }
                            easyVideoPlayerController.isSmoothing = false;
                            easyVideoPlayerController.startHideStateCountDown();
                            seekBarValueNotifier.value = null;
                          },
                        );
                      },
                    ),
                  ),
                ),
                Gaps.getHorizontal(trackPadding),
                Text(
                  getDurationFormat(easyVideoPlayerController.duration),
                  style: timeStyle,
                ),

                Gaps.getHorizontal(5),

                GestureDetector(
                  onTap: (){
                    easyVideoPlayerController.toggleFullScreen(context);
                  },
                  child: Icon(CupertinoIcons.viewfinder, size: getSp(25), color: Colors.white,),
                )
              ],
            )
          ],
        )
    );
  }


  String getDurationFormat(Duration duration){
    return RegExp(r'((^0*[1-9]\d*:)?\d{2}:\d{2})\.\d+$')
        .firstMatch("$duration")
        ?.group(1) ??
        '$duration';
  }

}
